#pragma once
#include <Arduino.h>

void  motion_init();
void  motion_move_to(float x_mm, float y_mm, float feedrate_mm_per_min);
bool  motion_run();
bool  motion_is_idle();
void  motion_wait_idle();
void  motion_home();
void  motion_set_speed_multiplier(float mult);
float motion_get_speed_multiplier();
void  motion_enable();
void  motion_disable();
float motion_get_x_mm();
float motion_get_y_mm();
bool  motion_any_limit_triggered();
